summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorLinus Walleij <triad@df.lth.se>2012-12-26 12:00:52 +0100
committerLinus Walleij <triad@df.lth.se>2012-12-26 12:00:52 +0100
commit37b094568d7e844b923b346537fd1ddc74319b0e (patch)
tree74a2fbffd2f23fda8603347aa8b4b3893039d60f
parentb98184f0f02bd2f2874e7b6267213030c8d9747f (diff)
downloadlibmtp-37b094568d7e844b923b346537fd1ddc74319b0e.tar.gz
YiFang BQ Tesla
Signed-off-by: Linus Walleij <triad@df.lth.se>
-rw-r--r--logs/mtp-detect-yifang-tesla.txt74
-rw-r--r--src/music-players.h9
2 files changed, 80 insertions, 3 deletions
diff --git a/logs/mtp-detect-yifang-tesla.txt b/logs/mtp-detect-yifang-tesla.txt
new file mode 100644
index 0000000..00a4a8d
--- /dev/null
+++ b/logs/mtp-detect-yifang-tesla.txt
@@ -0,0 +1,74 @@
+libmtp version: 1.1.5
+
+Listing raw device(s)
+ No raw devices found.
+
+
+lsusb -v:
+Bus 002 Device 009: ID 2207:0006
+Device Descriptor:
+ bLength 18
+ bDescriptorType 1
+ bcdUSB 2.00
+ bDeviceClass 0 (Defined at Interface level)
+ bDeviceSubClass 0
+ bDeviceProtocol 0
+ bMaxPacketSize0 64
+ idVendor 0x2207
+ idProduct 0x0006
+ bcdDevice 2.22
+ iManufacturer 2 Yifang
+ iProduct 3 Tesla
+ iSerial 4 STM1007HD0123456
+ bNumConfigurations 1
+ Configuration Descriptor:
+ bLength 9
+ bDescriptorType 2
+ wTotalLength 32
+ bNumInterfaces 1
+ bConfigurationValue 1
+ iConfiguration 0
+ bmAttributes 0xc0
+ Self Powered
+ MaxPower 500mA
+ Interface Descriptor:
+ bLength 9
+ bDescriptorType 4
+ bInterfaceNumber 0
+ bAlternateSetting 0
+ bNumEndpoints 2
+ bInterfaceClass 255 Vendor Specific Class
+ bInterfaceSubClass 66
+ bInterfaceProtocol 1
+ iInterface 0
+ Endpoint Descriptor:
+ bLength 7
+ bDescriptorType 5
+ bEndpointAddress 0x81 EP 1 IN
+ bmAttributes 2
+ Transfer Type Bulk
+ Synch Type None
+ Usage Type Data
+ wMaxPacketSize 0x0040 1x 64 bytes
+ bInterval 0
+ Endpoint Descriptor:
+ bLength 7
+ bDescriptorType 5
+ bEndpointAddress 0x02 EP 2 OUT
+ bmAttributes 2
+ Transfer Type Bulk
+ Synch Type None
+ Usage Type Data
+ wMaxPacketSize 0x0200 1x 512 bytes
+ bInterval 0
+Device Qualifier (for other device speed):
+ bLength 10
+ bDescriptorType 6
+ bcdUSB 2.00
+ bDeviceClass 0 (Defined at Interface level)
+ bDeviceSubClass 0
+ bDeviceProtocol 0
+ bMaxPacketSize0 64
+ bNumConfigurations 1
+Device Status: 0x0001
+ Self Powered
diff --git a/src/music-players.h b/src/music-players.h
index 7d1a8e2..68cbbf9 100644
--- a/src/music-players.h
+++ b/src/music-players.h
@@ -2025,10 +2025,13 @@
DEVICE_FLAGS_ANDROID_BUGS },
/*
* Viewpia, bq...
* Seems like some multi-branded OEM product.
*/
- { "Various", 0x2207, "Viewpia DR/bq Kepler", 0x0001, DEVICE_FLAGS_ANDROID_BUGS },
+ { "Various", 0x2207, "Viewpia DR/bq Kepler", 0x0001,
+ DEVICE_FLAGS_ANDROID_BUGS },
+ { "YiFang", 0x2207, "BQ Tesla", 0x0006,
+ DEVICE_FLAGS_ANDROID_BUGS },
/*
* Kobo
@@ -2025,10 +2025,13 @@
DEVICE_FLAGS_ANDROID_BUGS },
/*
- * Viewpia, bq...
- * Seems like some multi-branded OEM product.
+ * Viewpia, bq, YiFang
+ * Seems like some multi-branded OEM product line.
*/